# thousandeyes-sdk-internet-insights
We are happy to announce the release of the Internet Insights API set. This limited release includes endpoints that:

* Make our catalog provider and Internet outage data accessible to API users.
* Provide access to advanced filtering, which is part of our next-generation API efforts to allow API users to fine-tune queries across all of our APIs in a consistent manner.

Internet Insights provide visibility into core Internet infrastructure, including ISPs, DNS providers, IaaS, CDNs , and SaaS providers.
It tracks the macro-level impact of Internet events on individual users and enterprise networks connecting at the edge of the Internet. These events include Outages, Routing hijacks and leaks, DDoS attacks, And political interference, among others.

Future releases of the Internet Insights API set will further unlock access to core Internet Insights functionality, unlocking potential integrations to enrich customer process flows.

For more information about Internet Insights, see the [Internet Insights](https://docs.thousandeyes.com/product-documentation/internet-insights).


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 7.0.41
- Generator version: 7.6.0
- Build package: com.thousandeyes.api.codegen.ThousandeyesPythonGenerator

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

Install directly via PyPi:

```sh
pip install thousandeyes-sdk-internet-insights
```
(you may need to run `pip` with root permission: `sudo pip install thousandeyes-sdk-internet-insights`)

Then import the package:
```python
import thousandeyes_sdk.internet_insights
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import thousandeyes_sdk.internet_insights
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the installation procedure and then run the following:

```python

import thousandeyes_sdk.core
import thousandeyes_sdk.internet_insights
from thousandeyes_sdk.core.exceptions import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.thousandeyes.com/v7
# See configuration.py for a list of all supported configuration parameters.
configuration = thousandeyes_sdk.core.Configuration(
    host = "https://api.thousandeyes.com/v7"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: BearerAuth
configuration = thousandeyes_sdk.core.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with thousandeyes_sdk.core.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = thousandeyes_sdk.internet_insights.InternetInsightsCatalogProvidersApi(api_client)
    api_catalog_provider_filter = thousandeyes_sdk.internet_insights.ApiCatalogProviderFilter() # ApiCatalogProviderFilter | 
    aid = '1234' # str | A unique identifier associated with your account group. You can retrieve your `AccountGroupId` from the `/account-groups` endpoint. Note that you must be assigned to the target account group. Specifying this parameter without being assigned to the target account group will result in an error response. (optional)

    try:
        # List catalog providers
        api_response = api_instance.filter_catalog_providers(api_catalog_provider_filter, aid=aid)
        print("The response of InternetInsightsCatalogProvidersApi->filter_catalog_providers:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling InternetInsightsCatalogProvidersApi->filter_catalog_providers: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.thousandeyes.com/v7*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*InternetInsightsCatalogProvidersApi* | [**filter_catalog_providers**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/InternetInsightsCatalogProvidersApi.md#filter_catalog_providers) | **POST** /internet-insights/catalog/providers/filter | List catalog providers
*InternetInsightsCatalogProvidersApi* | [**get_catalog_provider**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/InternetInsightsCatalogProvidersApi.md#get_catalog_provider) | **GET** /internet-insights/catalog/providers/{providerId} | Retrieve a catalog provider
*InternetInsightsOutagesApi* | [**filter_outages**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/InternetInsightsOutagesApi.md#filter_outages) | **POST** /internet-insights/outages/filter | List network and application outages
*InternetInsightsOutagesApi* | [**get_app_outage**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/InternetInsightsOutagesApi.md#get_app_outage) | **GET** /internet-insights/outages/app/{outageId} | Retrieve application outage
*InternetInsightsOutagesApi* | [**get_network_outage**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/InternetInsightsOutagesApi.md#get_network_outage) | **GET** /internet-insights/outages/net/{outageId} | Retrieve network outage


## Documentation For Models

 - [ApiApplicationOutageAffectedLocation](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiApplicationOutageAffectedLocation.md)
 - [ApiApplicationOutageAffectedServer](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiApplicationOutageAffectedServer.md)
 - [ApiApplicationOutageDetails](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiApplicationOutageDetails.md)
 - [ApiAsn](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiAsn.md)
 - [ApiCatalogProvider](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiCatalogProvider.md)
 - [ApiCatalogProviderDetails](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiCatalogProviderDetails.md)
 - [ApiCatalogProviderFilter](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiCatalogProviderFilter.md)
 - [ApiCatalogProviderResponse](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiCatalogProviderResponse.md)
 - [ApiNetworkOutageAffectedLocation](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiNetworkOutageAffectedLocation.md)
 - [ApiNetworkOutageDetails](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiNetworkOutageDetails.md)
 - [ApiOutage](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiOutage.md)
 - [ApiOutageFilter](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiOutageFilter.md)
 - [ApiOutagesResponse](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ApiOutagesResponse.md)
 - [Error](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/Error.md)
 - [InternetInsightsApiAffectedAgent](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/InternetInsightsApiAffectedAgent.md)
 - [InternetInsightsApiAffectedTest](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/InternetInsightsApiAffectedTest.md)
 - [Link](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/Link.md)
 - [OutageScope](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/OutageScope.md)
 - [ProviderLocation](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ProviderLocation.md)
 - [SelfLinks](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/SelfLinks.md)
 - [UnauthorizedError](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/UnauthorizedError.md)
 - [ValidationError](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ValidationError.md)
 - [ValidationErrorItem](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-internet-insights/docs/ValidationErrorItem.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="BearerAuth"></a>
### BearerAuth

- **Type**: Bearer authentication


## Author

<a href="mailto:api-team@thousandeyes.com">ThousandEyes API Team </a>


